# coding: utf-8

"""
    Agent Management API

    API for managing agents, their templates, and call logs

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, StrictInt, StrictStr
from typing import Optional
from typing_extensions import Annotated
from smallestai.atoms.models.agent_agent_id_webhook_subscriptions_delete200_response import AgentAgentIdWebhookSubscriptionsDelete200Response
from smallestai.atoms.models.agent_agent_id_webhook_subscriptions_get200_response import AgentAgentIdWebhookSubscriptionsGet200Response
from smallestai.atoms.models.agent_agent_id_webhook_subscriptions_post201_response import AgentAgentIdWebhookSubscriptionsPost201Response
from smallestai.atoms.models.agent_agent_id_webhook_subscriptions_post_request import AgentAgentIdWebhookSubscriptionsPostRequest
from smallestai.atoms.models.agent_from_template_post200_response import AgentFromTemplatePost200Response
from smallestai.atoms.models.agent_get200_response import AgentGet200Response
from smallestai.atoms.models.agent_id_delete200_response import AgentIdDelete200Response
from smallestai.atoms.models.agent_id_get200_response import AgentIdGet200Response
from smallestai.atoms.models.agent_id_patch200_response import AgentIdPatch200Response
from smallestai.atoms.models.agent_id_patch_request import AgentIdPatchRequest
from smallestai.atoms.models.agent_id_workflow_get200_response import AgentIdWorkflowGet200Response
from smallestai.atoms.models.create_agent_request import CreateAgentRequest

from smallestai.atoms.api_client import ApiClient, RequestSerialized
from smallestai.atoms.api_response import ApiResponse
from smallestai.atoms.rest import RESTResponseType


class AgentsApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def agent_agent_id_webhook_subscriptions_delete(
        self,
        agent_id: Annotated[StrictStr, Field(description="The ID of the agent to filter subscriptions by")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> AgentAgentIdWebhookSubscriptionsDelete200Response:
        """Delete webhook subscriptions for an agent

        Delete webhook subscriptions for a given agent ID

        :param agent_id: The ID of the agent to filter subscriptions by (required)
        :type agent_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._agent_agent_id_webhook_subscriptions_delete_serialize(
            agent_id=agent_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "AgentAgentIdWebhookSubscriptionsDelete200Response",
            '400': "BadRequestErrorResponse",
            '401': "UnauthorizedErrorReponse",
            '404': "AgentAgentIdWebhookSubscriptionsGet404Response",
            '500': "InternalServerErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def agent_agent_id_webhook_subscriptions_delete_with_http_info(
        self,
        agent_id: Annotated[StrictStr, Field(description="The ID of the agent to filter subscriptions by")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[AgentAgentIdWebhookSubscriptionsDelete200Response]:
        """Delete webhook subscriptions for an agent

        Delete webhook subscriptions for a given agent ID

        :param agent_id: The ID of the agent to filter subscriptions by (required)
        :type agent_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._agent_agent_id_webhook_subscriptions_delete_serialize(
            agent_id=agent_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "AgentAgentIdWebhookSubscriptionsDelete200Response",
            '400': "BadRequestErrorResponse",
            '401': "UnauthorizedErrorReponse",
            '404': "AgentAgentIdWebhookSubscriptionsGet404Response",
            '500': "InternalServerErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def agent_agent_id_webhook_subscriptions_delete_without_preload_content(
        self,
        agent_id: Annotated[StrictStr, Field(description="The ID of the agent to filter subscriptions by")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Delete webhook subscriptions for an agent

        Delete webhook subscriptions for a given agent ID

        :param agent_id: The ID of the agent to filter subscriptions by (required)
        :type agent_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._agent_agent_id_webhook_subscriptions_delete_serialize(
            agent_id=agent_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "AgentAgentIdWebhookSubscriptionsDelete200Response",
            '400': "BadRequestErrorResponse",
            '401': "UnauthorizedErrorReponse",
            '404': "AgentAgentIdWebhookSubscriptionsGet404Response",
            '500': "InternalServerErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _agent_agent_id_webhook_subscriptions_delete_serialize(
        self,
        agent_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if agent_id is not None:
            _path_params['agentId'] = agent_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'BearerAuth'
        ]

        return self.api_client.param_serialize(
            method='DELETE',
            resource_path='/agent/{agentId}/webhook-subscriptions',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def agent_agent_id_webhook_subscriptions_get(
        self,
        agent_id: Annotated[StrictStr, Field(description="The ID of the agent")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> AgentAgentIdWebhookSubscriptionsGet200Response:
        """Get webhook subscriptions for an agent

        Retrieve webhook subscriptions for a given agent ID

        :param agent_id: The ID of the agent (required)
        :type agent_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._agent_agent_id_webhook_subscriptions_get_serialize(
            agent_id=agent_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "AgentAgentIdWebhookSubscriptionsGet200Response",
            '400': "BadRequestErrorResponse",
            '401': "UnauthorizedErrorReponse",
            '404': "AgentAgentIdWebhookSubscriptionsGet404Response",
            '500': "InternalServerErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def agent_agent_id_webhook_subscriptions_get_with_http_info(
        self,
        agent_id: Annotated[StrictStr, Field(description="The ID of the agent")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[AgentAgentIdWebhookSubscriptionsGet200Response]:
        """Get webhook subscriptions for an agent

        Retrieve webhook subscriptions for a given agent ID

        :param agent_id: The ID of the agent (required)
        :type agent_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._agent_agent_id_webhook_subscriptions_get_serialize(
            agent_id=agent_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "AgentAgentIdWebhookSubscriptionsGet200Response",
            '400': "BadRequestErrorResponse",
            '401': "UnauthorizedErrorReponse",
            '404': "AgentAgentIdWebhookSubscriptionsGet404Response",
            '500': "InternalServerErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def agent_agent_id_webhook_subscriptions_get_without_preload_content(
        self,
        agent_id: Annotated[StrictStr, Field(description="The ID of the agent")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get webhook subscriptions for an agent

        Retrieve webhook subscriptions for a given agent ID

        :param agent_id: The ID of the agent (required)
        :type agent_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._agent_agent_id_webhook_subscriptions_get_serialize(
            agent_id=agent_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "AgentAgentIdWebhookSubscriptionsGet200Response",
            '400': "BadRequestErrorResponse",
            '401': "UnauthorizedErrorReponse",
            '404': "AgentAgentIdWebhookSubscriptionsGet404Response",
            '500': "InternalServerErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _agent_agent_id_webhook_subscriptions_get_serialize(
        self,
        agent_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if agent_id is not None:
            _path_params['agentId'] = agent_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'BearerAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/agent/{agentId}/webhook-subscriptions',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def agent_agent_id_webhook_subscriptions_post(
        self,
        agent_id: Annotated[StrictStr, Field(description="The ID of the agent to create subscriptions for")],
        agent_agent_id_webhook_subscriptions_post_request: AgentAgentIdWebhookSubscriptionsPostRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> AgentAgentIdWebhookSubscriptionsPost201Response:
        """Create webhook subscriptions for an agent

        Create webhook subscriptions for a specific agent with selected event types

        :param agent_id: The ID of the agent to create subscriptions for (required)
        :type agent_id: str
        :param agent_agent_id_webhook_subscriptions_post_request: (required)
        :type agent_agent_id_webhook_subscriptions_post_request: AgentAgentIdWebhookSubscriptionsPostRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._agent_agent_id_webhook_subscriptions_post_serialize(
            agent_id=agent_id,
            agent_agent_id_webhook_subscriptions_post_request=agent_agent_id_webhook_subscriptions_post_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '201': "AgentAgentIdWebhookSubscriptionsPost201Response",
            '400': "AgentAgentIdWebhookSubscriptionsPost400Response",
            '401': "UnauthorizedErrorReponse",
            '404': "AgentAgentIdWebhookSubscriptionsGet404Response",
            '500': "InternalServerErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def agent_agent_id_webhook_subscriptions_post_with_http_info(
        self,
        agent_id: Annotated[StrictStr, Field(description="The ID of the agent to create subscriptions for")],
        agent_agent_id_webhook_subscriptions_post_request: AgentAgentIdWebhookSubscriptionsPostRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[AgentAgentIdWebhookSubscriptionsPost201Response]:
        """Create webhook subscriptions for an agent

        Create webhook subscriptions for a specific agent with selected event types

        :param agent_id: The ID of the agent to create subscriptions for (required)
        :type agent_id: str
        :param agent_agent_id_webhook_subscriptions_post_request: (required)
        :type agent_agent_id_webhook_subscriptions_post_request: AgentAgentIdWebhookSubscriptionsPostRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._agent_agent_id_webhook_subscriptions_post_serialize(
            agent_id=agent_id,
            agent_agent_id_webhook_subscriptions_post_request=agent_agent_id_webhook_subscriptions_post_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '201': "AgentAgentIdWebhookSubscriptionsPost201Response",
            '400': "AgentAgentIdWebhookSubscriptionsPost400Response",
            '401': "UnauthorizedErrorReponse",
            '404': "AgentAgentIdWebhookSubscriptionsGet404Response",
            '500': "InternalServerErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def agent_agent_id_webhook_subscriptions_post_without_preload_content(
        self,
        agent_id: Annotated[StrictStr, Field(description="The ID of the agent to create subscriptions for")],
        agent_agent_id_webhook_subscriptions_post_request: AgentAgentIdWebhookSubscriptionsPostRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Create webhook subscriptions for an agent

        Create webhook subscriptions for a specific agent with selected event types

        :param agent_id: The ID of the agent to create subscriptions for (required)
        :type agent_id: str
        :param agent_agent_id_webhook_subscriptions_post_request: (required)
        :type agent_agent_id_webhook_subscriptions_post_request: AgentAgentIdWebhookSubscriptionsPostRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._agent_agent_id_webhook_subscriptions_post_serialize(
            agent_id=agent_id,
            agent_agent_id_webhook_subscriptions_post_request=agent_agent_id_webhook_subscriptions_post_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '201': "AgentAgentIdWebhookSubscriptionsPost201Response",
            '400': "AgentAgentIdWebhookSubscriptionsPost400Response",
            '401': "UnauthorizedErrorReponse",
            '404': "AgentAgentIdWebhookSubscriptionsGet404Response",
            '500': "InternalServerErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _agent_agent_id_webhook_subscriptions_post_serialize(
        self,
        agent_id,
        agent_agent_id_webhook_subscriptions_post_request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if agent_id is not None:
            _path_params['agentId'] = agent_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if agent_agent_id_webhook_subscriptions_post_request is not None:
            _body_params = agent_agent_id_webhook_subscriptions_post_request


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'BearerAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/agent/{agentId}/webhook-subscriptions',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def agent_get(
        self,
        page: Optional[StrictInt] = None,
        offset: Optional[StrictInt] = None,
        search: Optional[StrictStr] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> AgentGet200Response:
        """Get all agents

        Agents are the main entities in the system. Agents are used to create conversations. You can create workflow for an agent and configure it for different use cases. You can also create custom workflows for an agent. This API will give you the list of agents created by organization you are a part of.

        :param page:
        :type page: int
        :param offset:
        :type offset: int
        :param search:
        :type search: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._agent_get_serialize(
            page=page,
            offset=offset,
            search=search,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "AgentGet200Response",
            '400': "BadRequestErrorResponse",
            '401': "UnauthorizedErrorReponse",
            '500': "InternalServerErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def agent_get_with_http_info(
        self,
        page: Optional[StrictInt] = None,
        offset: Optional[StrictInt] = None,
        search: Optional[StrictStr] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[AgentGet200Response]:
        """Get all agents

        Agents are the main entities in the system. Agents are used to create conversations. You can create workflow for an agent and configure it for different use cases. You can also create custom workflows for an agent. This API will give you the list of agents created by organization you are a part of.

        :param page:
        :type page: int
        :param offset:
        :type offset: int
        :param search:
        :type search: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._agent_get_serialize(
            page=page,
            offset=offset,
            search=search,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "AgentGet200Response",
            '400': "BadRequestErrorResponse",
            '401': "UnauthorizedErrorReponse",
            '500': "InternalServerErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def agent_get_without_preload_content(
        self,
        page: Optional[StrictInt] = None,
        offset: Optional[StrictInt] = None,
        search: Optional[StrictStr] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get all agents

        Agents are the main entities in the system. Agents are used to create conversations. You can create workflow for an agent and configure it for different use cases. You can also create custom workflows for an agent. This API will give you the list of agents created by organization you are a part of.

        :param page:
        :type page: int
        :param offset:
        :type offset: int
        :param search:
        :type search: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._agent_get_serialize(
            page=page,
            offset=offset,
            search=search,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "AgentGet200Response",
            '400': "BadRequestErrorResponse",
            '401': "UnauthorizedErrorReponse",
            '500': "InternalServerErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _agent_get_serialize(
        self,
        page,
        offset,
        search,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if page is not None:
            
            _query_params.append(('page', page))
            
        if offset is not None:
            
            _query_params.append(('offset', offset))
            
        if search is not None:
            
            _query_params.append(('search', search))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'BearerAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/agent',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def agent_id_delete(
        self,
        id: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> AgentIdDelete200Response:
        """Delete an agent


        :param id: (required)
        :type id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._agent_id_delete_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "AgentIdDelete200Response",
            '400': "BadRequestErrorResponse",
            '401': "ApiResponse",
            '403': "ApiResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def agent_id_delete_with_http_info(
        self,
        id: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[AgentIdDelete200Response]:
        """Delete an agent


        :param id: (required)
        :type id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._agent_id_delete_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "AgentIdDelete200Response",
            '400': "BadRequestErrorResponse",
            '401': "ApiResponse",
            '403': "ApiResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def agent_id_delete_without_preload_content(
        self,
        id: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Delete an agent


        :param id: (required)
        :type id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._agent_id_delete_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "AgentIdDelete200Response",
            '400': "BadRequestErrorResponse",
            '401': "ApiResponse",
            '403': "ApiResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _agent_id_delete_serialize(
        self,
        id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if id is not None:
            _path_params['id'] = id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'BearerAuth'
        ]

        return self.api_client.param_serialize(
            method='DELETE',
            resource_path='/agent/{id}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def agent_id_get(
        self,
        id: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> AgentIdGet200Response:
        """Get agent by ID

        Agents are the main entities in the system. Agents are used to create conversations. You can create workflow for an agent and configure it for different use cases. You can also create custom workflows for an agent.

        :param id: (required)
        :type id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._agent_id_get_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "AgentIdGet200Response",
            '400': "BadRequestErrorResponse",
            '401': "UnauthorizedErrorReponse",
            '500': "InternalServerErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def agent_id_get_with_http_info(
        self,
        id: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[AgentIdGet200Response]:
        """Get agent by ID

        Agents are the main entities in the system. Agents are used to create conversations. You can create workflow for an agent and configure it for different use cases. You can also create custom workflows for an agent.

        :param id: (required)
        :type id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._agent_id_get_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "AgentIdGet200Response",
            '400': "BadRequestErrorResponse",
            '401': "UnauthorizedErrorReponse",
            '500': "InternalServerErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def agent_id_get_without_preload_content(
        self,
        id: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get agent by ID

        Agents are the main entities in the system. Agents are used to create conversations. You can create workflow for an agent and configure it for different use cases. You can also create custom workflows for an agent.

        :param id: (required)
        :type id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._agent_id_get_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "AgentIdGet200Response",
            '400': "BadRequestErrorResponse",
            '401': "UnauthorizedErrorReponse",
            '500': "InternalServerErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _agent_id_get_serialize(
        self,
        id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if id is not None:
            _path_params['id'] = id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'BearerAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/agent/{id}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def agent_id_patch(
        self,
        id: StrictStr,
        agent_id_patch_request: AgentIdPatchRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> AgentIdPatch200Response:
        """Update an agent


        :param id: (required)
        :type id: str
        :param agent_id_patch_request: (required)
        :type agent_id_patch_request: AgentIdPatchRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._agent_id_patch_serialize(
            id=id,
            agent_id_patch_request=agent_id_patch_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "AgentIdPatch200Response",
            '400': "BadRequestErrorResponse",
            '401': "ApiResponse",
            '500': "InternalServerErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def agent_id_patch_with_http_info(
        self,
        id: StrictStr,
        agent_id_patch_request: AgentIdPatchRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[AgentIdPatch200Response]:
        """Update an agent


        :param id: (required)
        :type id: str
        :param agent_id_patch_request: (required)
        :type agent_id_patch_request: AgentIdPatchRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._agent_id_patch_serialize(
            id=id,
            agent_id_patch_request=agent_id_patch_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "AgentIdPatch200Response",
            '400': "BadRequestErrorResponse",
            '401': "ApiResponse",
            '500': "InternalServerErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def agent_id_patch_without_preload_content(
        self,
        id: StrictStr,
        agent_id_patch_request: AgentIdPatchRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Update an agent


        :param id: (required)
        :type id: str
        :param agent_id_patch_request: (required)
        :type agent_id_patch_request: AgentIdPatchRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._agent_id_patch_serialize(
            id=id,
            agent_id_patch_request=agent_id_patch_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "AgentIdPatch200Response",
            '400': "BadRequestErrorResponse",
            '401': "ApiResponse",
            '500': "InternalServerErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _agent_id_patch_serialize(
        self,
        id,
        agent_id_patch_request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if id is not None:
            _path_params['id'] = id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if agent_id_patch_request is not None:
            _body_params = agent_id_patch_request


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'BearerAuth'
        ]

        return self.api_client.param_serialize(
            method='PATCH',
            resource_path='/agent/{id}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def agent_id_workflow_get(
        self,
        id: Annotated[StrictStr, Field(description="The ID of the agent")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> AgentIdWorkflowGet200Response:
        """Get agent workflow

        Retrieve the workflow configuration for a specific agent. The workflow contains nodes and edges that define the conversation flow and logic for the agent.

        :param id: The ID of the agent (required)
        :type id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._agent_id_workflow_get_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "AgentIdWorkflowGet200Response",
            '400': "BadRequestErrorResponse",
            '401': "UnauthorizedErrorReponse",
            '404': "AgentIdWorkflowGet404Response",
            '500': "InternalServerErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def agent_id_workflow_get_with_http_info(
        self,
        id: Annotated[StrictStr, Field(description="The ID of the agent")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[AgentIdWorkflowGet200Response]:
        """Get agent workflow

        Retrieve the workflow configuration for a specific agent. The workflow contains nodes and edges that define the conversation flow and logic for the agent.

        :param id: The ID of the agent (required)
        :type id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._agent_id_workflow_get_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "AgentIdWorkflowGet200Response",
            '400': "BadRequestErrorResponse",
            '401': "UnauthorizedErrorReponse",
            '404': "AgentIdWorkflowGet404Response",
            '500': "InternalServerErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def agent_id_workflow_get_without_preload_content(
        self,
        id: Annotated[StrictStr, Field(description="The ID of the agent")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get agent workflow

        Retrieve the workflow configuration for a specific agent. The workflow contains nodes and edges that define the conversation flow and logic for the agent.

        :param id: The ID of the agent (required)
        :type id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._agent_id_workflow_get_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "AgentIdWorkflowGet200Response",
            '400': "BadRequestErrorResponse",
            '401': "UnauthorizedErrorReponse",
            '404': "AgentIdWorkflowGet404Response",
            '500': "InternalServerErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _agent_id_workflow_get_serialize(
        self,
        id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if id is not None:
            _path_params['id'] = id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'BearerAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/agent/{id}/workflow',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def agent_post(
        self,
        create_agent_request: CreateAgentRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> AgentFromTemplatePost200Response:
        """Create a new agent

        You can create a new agent by passing the name of the agent in the request body.

        :param create_agent_request: (required)
        :type create_agent_request: CreateAgentRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._agent_post_serialize(
            create_agent_request=create_agent_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '201': "AgentFromTemplatePost200Response",
            '400': "BadRequestErrorResponse",
            '401': "UnauthorizedErrorReponse",
            '500': "InternalServerErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def agent_post_with_http_info(
        self,
        create_agent_request: CreateAgentRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[AgentFromTemplatePost200Response]:
        """Create a new agent

        You can create a new agent by passing the name of the agent in the request body.

        :param create_agent_request: (required)
        :type create_agent_request: CreateAgentRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._agent_post_serialize(
            create_agent_request=create_agent_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '201': "AgentFromTemplatePost200Response",
            '400': "BadRequestErrorResponse",
            '401': "UnauthorizedErrorReponse",
            '500': "InternalServerErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def agent_post_without_preload_content(
        self,
        create_agent_request: CreateAgentRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Create a new agent

        You can create a new agent by passing the name of the agent in the request body.

        :param create_agent_request: (required)
        :type create_agent_request: CreateAgentRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._agent_post_serialize(
            create_agent_request=create_agent_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '201': "AgentFromTemplatePost200Response",
            '400': "BadRequestErrorResponse",
            '401': "UnauthorizedErrorReponse",
            '500': "InternalServerErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _agent_post_serialize(
        self,
        create_agent_request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if create_agent_request is not None:
            _body_params = create_agent_request


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'BearerAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/agent',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# This file was auto-generated by Fern from our API Definition.

import typing
from json.decoder import JSONDecodeError

from ...core.api_error import ApiError
from ...core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ...core.http_response import AsyncHttpResponse, HttpResponse
from ...core.jsonable_encoder import jsonable_encoder
from ...core.request_options import RequestOptions
from ...core.serialization import convert_and_respect_annotation_metadata
from ...core.unchecked_base_model import construct_type
from ..errors.bad_request_error import BadRequestError
from ..errors.internal_server_error import InternalServerError
from ..errors.not_found_error import NotFoundError
from ..errors.unauthorized_error import UnauthorizedError
from ..types.single_prompt_config import SinglePromptConfig
from ..types.workflow_type import WorkflowType
from .types.patch_workflow_id_request_workflow_graph import PatchWorkflowIdRequestWorkflowGraph
from .types.patch_workflow_id_response import PatchWorkflowIdResponse

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class RawWorkflowsClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def update_workflow_configuration(
        self,
        id: str,
        *,
        type: WorkflowType,
        workflow_graph: typing.Optional[PatchWorkflowIdRequestWorkflowGraph] = OMIT,
        single_prompt_config: typing.Optional[SinglePromptConfig] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[PatchWorkflowIdResponse]:
        """
        Update workflow configuration for an agent. Currently available for single_prompt workflows only. For workflow_graph configurations, please use the UI.

        Parameters
        ----------
        id : str
            The ID of the workflow to update

        type : WorkflowType
            The type of workflow (single_prompt or workflow_graph)

        workflow_graph : typing.Optional[PatchWorkflowIdRequestWorkflowGraph]
            Workflow graph configuration. Required when type is workflow_graph. Exactly one of workflowGraph or singlePromptConfig must be provided.

        single_prompt_config : typing.Optional[SinglePromptConfig]
            Configuration for single_prompt workflow type. Required when type is single_prompt. Exactly one of workflowGraph or singlePromptConfig must be provided.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[PatchWorkflowIdResponse]
            Workflow updated successfully
        """
        _response = self._client_wrapper.httpx_client.request(
            f"workflow/{jsonable_encoder(id)}",
            base_url=self._client_wrapper.get_environment().atoms,
            method="PATCH",
            json={
                "type": type,
                "workflowGraph": convert_and_respect_annotation_metadata(
                    object_=workflow_graph, annotation=PatchWorkflowIdRequestWorkflowGraph, direction="write"
                ),
                "singlePromptConfig": convert_and_respect_annotation_metadata(
                    object_=single_prompt_config, annotation=SinglePromptConfig, direction="write"
                ),
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    PatchWorkflowIdResponse,
                    construct_type(
                        type_=PatchWorkflowIdResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 401:
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 404:
                raise NotFoundError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)


class AsyncRawWorkflowsClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def update_workflow_configuration(
        self,
        id: str,
        *,
        type: WorkflowType,
        workflow_graph: typing.Optional[PatchWorkflowIdRequestWorkflowGraph] = OMIT,
        single_prompt_config: typing.Optional[SinglePromptConfig] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[PatchWorkflowIdResponse]:
        """
        Update workflow configuration for an agent. Currently available for single_prompt workflows only. For workflow_graph configurations, please use the UI.

        Parameters
        ----------
        id : str
            The ID of the workflow to update

        type : WorkflowType
            The type of workflow (single_prompt or workflow_graph)

        workflow_graph : typing.Optional[PatchWorkflowIdRequestWorkflowGraph]
            Workflow graph configuration. Required when type is workflow_graph. Exactly one of workflowGraph or singlePromptConfig must be provided.

        single_prompt_config : typing.Optional[SinglePromptConfig]
            Configuration for single_prompt workflow type. Required when type is single_prompt. Exactly one of workflowGraph or singlePromptConfig must be provided.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[PatchWorkflowIdResponse]
            Workflow updated successfully
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"workflow/{jsonable_encoder(id)}",
            base_url=self._client_wrapper.get_environment().atoms,
            method="PATCH",
            json={
                "type": type,
                "workflowGraph": convert_and_respect_annotation_metadata(
                    object_=workflow_graph, annotation=PatchWorkflowIdRequestWorkflowGraph, direction="write"
                ),
                "singlePromptConfig": convert_and_respect_annotation_metadata(
                    object_=single_prompt_config, annotation=SinglePromptConfig, direction="write"
                ),
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    PatchWorkflowIdResponse,
                    construct_type(
                        type_=PatchWorkflowIdResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 401:
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 404:
                raise NotFoundError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
import typing_extensions
from ...core.pydantic_utilities import IS_PYDANTIC_V2
from ...core.serialization import FieldMetadata
from ...core.unchecked_base_model import UncheckedBaseModel


class KnowledgeBase(UncheckedBaseModel):
    id: typing_extensions.Annotated[
        str,
        FieldMetadata(alias="_id"),
        pydantic.Field(alias="_id", description="The unique identifier for the knowledge base"),
    ]
    name: str = pydantic.Field()
    """
    The name of the knowledge base
    """

    description: typing.Optional[str] = pydantic.Field(default=None)
    """
    The description of the knowledge base
    """

    organization: str = pydantic.Field()
    """
    The organization ID
    """

    created_by: typing_extensions.Annotated[
        str,
        FieldMetadata(alias="createdBy"),
        pydantic.Field(alias="createdBy", description="The user ID who created the knowledge base"),
    ]
    created_at: typing_extensions.Annotated[
        typing.Optional[dt.datetime],
        FieldMetadata(alias="createdAt"),
        pydantic.Field(alias="createdAt", description="The date and time when the knowledge base was created"),
    ] = None
    updated_at: typing_extensions.Annotated[
        typing.Optional[dt.datetime],
        FieldMetadata(alias="updatedAt"),
        pydantic.Field(alias="updatedAt", description="The date and time when the knowledge base was last updated"),
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ....core.pydantic_utilities import IS_PYDANTIC_V2
from ....core.unchecked_base_model import UncheckedBaseModel
from .get_campaign_id_response_data_campaign import GetCampaignIdResponseDataCampaign
from .get_campaign_id_response_data_events_item import GetCampaignIdResponseDataEventsItem
from .get_campaign_id_response_data_metrics import GetCampaignIdResponseDataMetrics


class GetCampaignIdResponseData(UncheckedBaseModel):
    campaign: typing.Optional[GetCampaignIdResponseDataCampaign] = None
    events: typing.Optional[typing.List[GetCampaignIdResponseDataEventsItem]] = pydantic.Field(default=None)
    """
    Campaign events history
    """

    metrics: typing.Optional[GetCampaignIdResponseDataMetrics] = pydantic.Field(default=None)
    """
    Campaign performance metrics
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ....core.pydantic_utilities import IS_PYDANTIC_V2
from ....core.unchecked_base_model import UncheckedBaseModel
from .stream_tts_request_message_language import StreamTtsRequestMessageLanguage


class StreamTtsRequestMessage(UncheckedBaseModel):
    voice_id: str = pydantic.Field()
    """
    Voice identifier (e.g., 'aditi', 'male-1', 'female-2')
    """

    text: str = pydantic.Field()
    """
    The text to convert to speech. Can be sent incrementally for streaming input.
    """

    is_streaming: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Indicates if this is part of a streaming text input sequence
    """

    is_final: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Indicates if this is the final chunk in a streaming sequence
    """

    language: typing.Optional[StreamTtsRequestMessageLanguage] = pydantic.Field(default=None)
    """
    Language code for synthesis
    """

    sample_rate: typing.Optional[int] = pydantic.Field(default=None)
    """
    Audio sample rate in Hz
    """

    speed: typing.Optional[float] = pydantic.Field(default=None)
    """
    Speech speed multiplier (0.5 = half speed, 1.0 = normal speed, 2.0 = double speed)
    """

    consistency: typing.Optional[float] = pydantic.Field(default=None)
    """
    Voice consistency parameter for maintaining voice characteristics
    """

    enhancement: typing.Optional[int] = pydantic.Field(default=None)
    """
    Audio enhancement level for improved quality
    """

    similarity: typing.Optional[float] = pydantic.Field(default=None)
    """
    Voice similarity parameter for voice matching
    """

    max_buffer_flush_ms: typing.Optional[int] = pydantic.Field(default=None)
    """
    Maximum buffer time in milliseconds before forcing audio output for low-latency applications
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2
from ...core.unchecked_base_model import UncheckedBaseModel
from .workflow_graph_data_edges_item import WorkflowGraphDataEdgesItem
from .workflow_graph_data_nodes_item import WorkflowGraphDataNodesItem


class WorkflowGraphData(UncheckedBaseModel):
    """
    Workflow configuration using a node-based graph structure
    """

    nodes: typing.Optional[typing.List[WorkflowGraphDataNodesItem]] = pydantic.Field(default=None)
    """
    Array of workflow nodes
    """

    edges: typing.Optional[typing.List[WorkflowGraphDataEdgesItem]] = pydantic.Field(default=None)
    """
    Array of workflow edges connecting nodes
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from . import atoms, waves
    from .atoms.helpers.atoms_client import AtomsClient
    from .atoms.client import AsyncAtomsClient
    from .client import AsyncSmallestAI, SmallestAI
    from .version import __version__
    from .waves.async_waves_client import AsyncWavesClient
    from .waves.waves_client import WavesClient
    from .waves.stream_tts import WavesStreamingTTS
    # OpenAPI backward-compat: API classes
    from .atoms.api.agent_templates_api import AgentTemplatesApi
    from .atoms.api.agents_api import AgentsApi
    from .atoms.api.calls_api import CallsApi
    from .atoms.api.campaigns_api import CampaignsApi
    from .atoms.api.knowledge_base_api import KnowledgeBaseApi
    from .atoms.api.logs_api import LogsApi
    from .atoms.api.organization_api import OrganizationApi
    from .atoms.api.user_api import UserApi
    # OpenAPI backward-compat: infrastructure
    from .atoms.api_response import ApiResponse
    from .atoms.api_client import ApiClient
    from .atoms.configuration import Configuration
    from .atoms.exceptions import (
        OpenApiException,
        ApiTypeError,
        ApiValueError,
        ApiKeyError,
        ApiAttributeError,
        ApiException,
    )
    # OpenAPI backward-compat: models
    from .atoms.models import (
        AgentDTO,
        AgentDTOLanguage,
        AgentDTOSynthesizer,
        AgentDTOSynthesizerVoiceConfig,
        AgentFromTemplatePost200Response,
        AgentGet200Response,
        AgentIdDelete200Response,
        AgentIdGet200Response,
        AgentIdPatch200Response,
        AgentIdPatchRequest,
        AgentIdPatchRequestLanguage,
        AgentIdPatchRequestSynthesizer,
        AgentIdPatchRequestSynthesizerVoiceConfig,
        AgentIdPatchRequestSynthesizerVoiceConfigOneOf,
        AgentIdPatchRequestSynthesizerVoiceConfigOneOf1,
        AgentTemplateGet200Response,
        AgentTemplateGet200ResponseDataInner,
        BadRequestErrorResponse,
        CreateAgentFromTemplateRequest,
        CreateAgentRequest,
        CreateAgentRequestLanguage,
        CreateAgentRequestLanguageSynthesizer,
        CreateAgentRequestLanguageSynthesizerVoiceConfig,
        CampaignPost201Response,
        CampaignPostRequest,
        CampaignGetRequest,
        CampaignGet200Response,
        CampaignIdGet200Response,
        ConversationIdGet200Response,
        ConversationIdGet200ResponseData,
        ConversationOutboundPost200Response,
        ConversationOutboundPost200ResponseData,
        ConversationOutboundPostRequest,
        InternalServerErrorResponse,
        KnowledgebaseIdGet200Response,
        KnowledgebasePost201Response,
        KnowledgebasePostRequest,
        KnowledgebaseIdItemsUploadTextPostRequest,
        OrganizationGet200Response,
        OrganizationGet200ResponseData,
        OrganizationGet200ResponseDataMembersInner,
        OrganizationGet200ResponseDataSubscription,
        UnauthorizedErrorReponse,
        UserGet200Response,
        UserGet200ResponseData,
        AgentAgentIdWebhookSubscriptionsDelete200Response,
        AgentAgentIdWebhookSubscriptionsGet200Response,
        AgentAgentIdWebhookSubscriptionsGet404Response,
        AgentAgentIdWebhookSubscriptionsPost201Response,
        AgentAgentIdWebhookSubscriptionsPost400Response,
        AgentAgentIdWebhookSubscriptionsPostRequest,
        Webhook,
        WebhookAgent,
        WebhookEvent,
        WebhookGet200Response,
        WebhookGet200ResponseData,
        WebhookIdDelete404Response,
        WebhookPost201Response,
        WebhookPostRequest,
        WebhookPostRequestEventsInner,
        WebhookSubscription,
        WebhookSubscriptionPopulated,
        AgentIdWorkflowGet200Response,
        AgentIdWorkflowGet200ResponseData,
        AgentIdWorkflowGet200ResponseDataEdgesInner,
        AgentIdWorkflowGet200ResponseDataEdgesInnerData,
        AgentIdWorkflowGet200ResponseDataEdgesInnerMarkerEnd,
        AgentIdWorkflowGet200ResponseDataNodesInner,
        AgentIdWorkflowGet200ResponseDataNodesInnerData,
        AgentIdWorkflowGet200ResponseDataNodesInnerDataVariables,
        AgentIdWorkflowGet200ResponseDataNodesInnerDataVariablesDataInner,
        AgentIdWorkflowGet200ResponseDataNodesInnerPosition,
        AgentIdWorkflowGet404Response,
        AudienceGet200Response,
        AudienceGet200ResponseDataInner,
        AudienceIdDelete200Response,
        AudienceIdDelete400Response,
        AudienceIdGet200Response,
        AudienceIdGet400Response,
        AudienceIdGet403Response,
        AudienceIdGet404Response,
        AudienceIdMembersDelete200Response,
        AudienceIdMembersDelete200ResponseData,
        AudienceIdMembersDeleteRequest,
        AudienceIdMembersGet200Response,
        AudienceIdMembersGet200ResponseData,
        AudienceIdMembersGet200ResponseDataMembersInner,
        AudienceIdMembersGet400Response,
        AudienceIdMembersGet500Response,
        AudienceIdMembersPost200Response,
        AudienceIdMembersPost200ResponseDataInner,
        AudienceIdMembersPost200ResponseDataInnerData,
        AudienceIdMembersPost400Response,
        AudienceIdMembersPost403Response,
        AudienceIdMembersPostRequest,
        AudienceIdMembersSearchGet200Response,
        AudienceIdMembersSearchGet200ResponseData,
        AudienceIdMembersSearchGet200ResponseDataSearchInfo,
        AudienceIdMembersSearchGet400Response,
        AudienceIdMembersSearchGet500Response,
        AudiencePost200Response,
        AudiencePost200ResponseData,
        AudiencePost400Response,
        AgentDTOLanguageSwitching,
        CampaignIdGet200ResponseData,
    )

_dynamic_imports: typing.Dict[str, str] = {
    # Submodules
    "atoms": ".atoms",
    "waves": ".waves",
    # Version
    "__version__": ".version",
    # Fern clients
    "AsyncAtomsClient": ".atoms.client",
    "AsyncSmallestAI": ".client",
    "SmallestAI": ".client",
    # Production clients (matching v4.3.1 behavior)
    "AtomsClient": ".atoms.atoms_client",
    "Audience": ".atoms.helpers.audience",
    "Call": ".atoms.helpers.call",
    "Campaign": ".atoms.helpers.campaign",
    "KB": ".atoms.helpers.kb",
    "AsyncWavesClient": ".waves.async_waves_client",
    "WavesClient": ".waves.waves_client",
    "WavesStreamingTTS": ".waves.stream_tts",
    "TTSConfig": ".waves.stream_tts",
    # OpenAPI backward-compat: API classes
    "AgentTemplatesApi": ".atoms.api.agent_templates_api",
    "AgentsApi": ".atoms.api.agents_api",
    "CallsApi": ".atoms.api.calls_api",
    "CampaignsApi": ".atoms.api.campaigns_api",
    "KnowledgeBaseApi": ".atoms.api.knowledge_base_api",
    "LogsApi": ".atoms.api.logs_api",
    "OrganizationApi": ".atoms.api.organization_api",
    "UserApi": ".atoms.api.user_api",
    # OpenAPI backward-compat: infrastructure
    "ApiResponse": ".atoms.api_response",
    "ApiClient": ".atoms.api_client",
    "Configuration": ".atoms.configuration",
    "OpenApiException": ".atoms.exceptions",
    "ApiTypeError": ".atoms.exceptions",
    "ApiValueError": ".atoms.exceptions",
    "ApiKeyError": ".atoms.exceptions",
    "ApiAttributeError": ".atoms.exceptions",
    "ApiException": ".atoms.exceptions",
    # OpenAPI backward-compat: models
    "AgentDTO": ".atoms.models",
    "AgentDTOLanguage": ".atoms.models",
    "AgentDTOSynthesizer": ".atoms.models",
    "AgentDTOSynthesizerVoiceConfig": ".atoms.models",
    "AgentFromTemplatePost200Response": ".atoms.models",
    "AgentGet200Response": ".atoms.models",
    "AgentIdDelete200Response": ".atoms.models",
    "AgentIdGet200Response": ".atoms.models",
    "AgentIdPatch200Response": ".atoms.models",
    "AgentIdPatchRequest": ".atoms.models",
    "AgentIdPatchRequestLanguage": ".atoms.models",
    "AgentIdPatchRequestSynthesizer": ".atoms.models",
    "AgentIdPatchRequestSynthesizerVoiceConfig": ".atoms.models",
    "AgentIdPatchRequestSynthesizerVoiceConfigOneOf": ".atoms.models",
    "AgentIdPatchRequestSynthesizerVoiceConfigOneOf1": ".atoms.models",
    "AgentTemplateGet200Response": ".atoms.models",
    "AgentTemplateGet200ResponseDataInner": ".atoms.models",
    "BadRequestErrorResponse": ".atoms.models",
    "CreateAgentFromTemplateRequest": ".atoms.models",
    "CreateAgentRequest": ".atoms.models",
    "CreateAgentRequestLanguage": ".atoms.models",
    "CreateAgentRequestLanguageSynthesizer": ".atoms.models",
    "CreateAgentRequestLanguageSynthesizerVoiceConfig": ".atoms.models",
    "CampaignPost201Response": ".atoms.models",
    "CampaignPostRequest": ".atoms.models",
    "CampaignGetRequest": ".atoms.models",
    "CampaignGet200Response": ".atoms.models",
    "CampaignIdGet200Response": ".atoms.models",
    "ConversationIdGet200Response": ".atoms.models",
    "ConversationIdGet200ResponseData": ".atoms.models",
    "ConversationOutboundPost200Response": ".atoms.models",
    "ConversationOutboundPost200ResponseData": ".atoms.models",
    "ConversationOutboundPostRequest": ".atoms.models",
    "InternalServerErrorResponse": ".atoms.models",
    "KnowledgebaseIdGet200Response": ".atoms.models",
    "KnowledgebasePost201Response": ".atoms.models",
    "KnowledgebasePostRequest": ".atoms.models",
    "KnowledgebaseIdItemsUploadTextPostRequest": ".atoms.models",
    "OrganizationGet200Response": ".atoms.models",
    "OrganizationGet200ResponseData": ".atoms.models",
    "OrganizationGet200ResponseDataMembersInner": ".atoms.models",
    "OrganizationGet200ResponseDataSubscription": ".atoms.models",
    "UnauthorizedErrorReponse": ".atoms.models",
    "UserGet200Response": ".atoms.models",
    "UserGet200ResponseData": ".atoms.models",
    # Additional models from v4.3.1
    "AgentGet200ResponseData": ".atoms.models",
    "AgentIdPatchRequestLanguageSwitching": ".atoms.models",
    "CampaignGet200ResponseData": ".atoms.models",
    "KnowledgeBase": ".atoms.models",
    "KnowledgeBaseItem": ".atoms.models",
    "KnowledgebaseGet200Response": ".atoms.models",
    "KnowledgebaseIdItemsGet200Response": ".atoms.models",
    "ProductPhoneNumbersGet200Response": ".atoms.models",
    "ProductPhoneNumbersGet200ResponseDataInner": ".atoms.models",
    "ProductPhoneNumbersGet200ResponseDataInnerAttributes": ".atoms.models",
    # Webhook models
    "AgentAgentIdWebhookSubscriptionsDelete200Response": ".atoms.models",
    "AgentAgentIdWebhookSubscriptionsGet200Response": ".atoms.models",
    "AgentAgentIdWebhookSubscriptionsGet404Response": ".atoms.models",
    "AgentAgentIdWebhookSubscriptionsPost201Response": ".atoms.models",
    "AgentAgentIdWebhookSubscriptionsPost400Response": ".atoms.models",
    "AgentAgentIdWebhookSubscriptionsPostRequest": ".atoms.models",
    "Webhook": ".atoms.models",
    "WebhookAgent": ".atoms.models",
    "WebhookEvent": ".atoms.models",
    "WebhookGet200Response": ".atoms.models",
    "WebhookGet200ResponseData": ".atoms.models",
    "WebhookIdDelete404Response": ".atoms.models",
    "WebhookPost201Response": ".atoms.models",
    "WebhookPostRequest": ".atoms.models",
    "WebhookPostRequestEventsInner": ".atoms.models",
    "WebhookSubscription": ".atoms.models",
    "WebhookSubscriptionPopulated": ".atoms.models",
    # Workflow models
    "AgentIdWorkflowGet200Response": ".atoms.models",
    "AgentIdWorkflowGet200ResponseData": ".atoms.models",
    "AgentIdWorkflowGet200ResponseDataEdgesInner": ".atoms.models",
    "AgentIdWorkflowGet200ResponseDataEdgesInnerData": ".atoms.models",
    "AgentIdWorkflowGet200ResponseDataEdgesInnerMarkerEnd": ".atoms.models",
    "AgentIdWorkflowGet200ResponseDataNodesInner": ".atoms.models",
    "AgentIdWorkflowGet200ResponseDataNodesInnerData": ".atoms.models",
    "AgentIdWorkflowGet200ResponseDataNodesInnerDataVariables": ".atoms.models",
    "AgentIdWorkflowGet200ResponseDataNodesInnerDataVariablesDataInner": ".atoms.models",
    "AgentIdWorkflowGet200ResponseDataNodesInnerPosition": ".atoms.models",
    "AgentIdWorkflowGet404Response": ".atoms.models",
    # Audience models
    "AudienceGet200Response": ".atoms.models",
    "AudienceGet200ResponseDataInner": ".atoms.models",
    "AudienceIdDelete200Response": ".atoms.models",
    "AudienceIdDelete400Response": ".atoms.models",
    "AudienceIdGet200Response": ".atoms.models",
    "AudienceIdGet400Response": ".atoms.models",
    "AudienceIdGet403Response": ".atoms.models",
    "AudienceIdGet404Response": ".atoms.models",
    "AudienceIdMembersDelete200Response": ".atoms.models",
    "AudienceIdMembersDelete200ResponseData": ".atoms.models",
    "AudienceIdMembersDeleteRequest": ".atoms.models",
    "AudienceIdMembersGet200Response": ".atoms.models",
    "AudienceIdMembersGet200ResponseData": ".atoms.models",
    "AudienceIdMembersGet200ResponseDataMembersInner": ".atoms.models",
    "AudienceIdMembersGet400Response": ".atoms.models",
    "AudienceIdMembersGet500Response": ".atoms.models",
    "AudienceIdMembersPost200Response": ".atoms.models",
    "AudienceIdMembersPost200ResponseDataInner": ".atoms.models",
    "AudienceIdMembersPost200ResponseDataInnerData": ".atoms.models",
    "AudienceIdMembersPost400Response": ".atoms.models",
    "AudienceIdMembersPost403Response": ".atoms.models",
    "AudienceIdMembersPostRequest": ".atoms.models",
    "AudienceIdMembersSearchGet200Response": ".atoms.models",
    "AudienceIdMembersSearchGet200ResponseData": ".atoms.models",
    "AudienceIdMembersSearchGet200ResponseDataSearchInfo": ".atoms.models",
    "AudienceIdMembersSearchGet400Response": ".atoms.models",
    "AudienceIdMembersSearchGet500Response": ".atoms.models",
    "AudiencePost200Response": ".atoms.models",
    "AudiencePost200ResponseData": ".atoms.models",
    "AudiencePost400Response": ".atoms.models",
    # Additional models
    "AgentDTOLanguageSwitching": ".atoms.models",
    "CampaignIdGet200ResponseData": ".atoms.models",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        if module_name == f".{attr_name}":
            return module
        else:
            return getattr(module, attr_name)
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    # Submodules
    "atoms",
    "waves",
    # Version
    "__version__",
    # Clients
    "AsyncAtomsClient",
    "AsyncSmallestAI",
    "AsyncWavesClient",
    "AtomsClient",
    "Audience",
    "Call",
    "Campaign",
    "KB",
    "SmallestAI",
    "WavesClient",
    "WavesStreamingTTS",
    "TTSConfig",
    # OpenAPI backward-compat: API classes
    "AgentTemplatesApi",
    "AgentsApi",
    "CallsApi",
    "CampaignsApi",
    "KnowledgeBaseApi",
    "LogsApi",
    "OrganizationApi",
    "UserApi",
    # OpenAPI backward-compat: infrastructure
    "ApiResponse",
    "ApiClient",
    "Configuration",
    "OpenApiException",
    "ApiTypeError",
    "ApiValueError",
    "ApiKeyError",
    "ApiAttributeError",
    "ApiException",
    # OpenAPI backward-compat: models
    "AgentDTO",
    "AgentDTOLanguage",
    "AgentDTOSynthesizer",
    "AgentDTOSynthesizerVoiceConfig",
    "AgentFromTemplatePost200Response",
    "AgentGet200Response",
    "AgentIdDelete200Response",
    "AgentIdGet200Response",
    "AgentIdPatch200Response",
    "AgentIdPatchRequest",
    "AgentIdPatchRequestLanguage",
    "AgentIdPatchRequestSynthesizer",
    "AgentIdPatchRequestSynthesizerVoiceConfig",
    "AgentIdPatchRequestSynthesizerVoiceConfigOneOf",
    "AgentIdPatchRequestSynthesizerVoiceConfigOneOf1",
    "AgentTemplateGet200Response",
    "AgentTemplateGet200ResponseDataInner",
    "BadRequestErrorResponse",
    "CreateAgentFromTemplateRequest",
    "CreateAgentRequest",
    "CreateAgentRequestLanguage",
    "CreateAgentRequestLanguageSynthesizer",
    "CreateAgentRequestLanguageSynthesizerVoiceConfig",
    "CampaignPost201Response",
    "CampaignPostRequest",
    "CampaignGetRequest",
    "CampaignGet200Response",
    "CampaignIdGet200Response",
    "ConversationIdGet200Response",
    "ConversationIdGet200ResponseData",
    "ConversationOutboundPost200Response",
    "ConversationOutboundPost200ResponseData",
    "ConversationOutboundPostRequest",
    "InternalServerErrorResponse",
    "KnowledgebaseIdGet200Response",
    "KnowledgebasePost201Response",
    "KnowledgebasePostRequest",
    "KnowledgebaseIdItemsUploadTextPostRequest",
    "OrganizationGet200Response",
    "OrganizationGet200ResponseData",
    "OrganizationGet200ResponseDataMembersInner",
    "OrganizationGet200ResponseDataSubscription",
    "UnauthorizedErrorReponse",
    "UserGet200Response",
    "UserGet200ResponseData",
    # Additional models from v4.3.1
    "AgentGet200ResponseData",
    "AgentIdPatchRequestLanguageSwitching",
    "CampaignGet200ResponseData",
    "KnowledgeBase",
    "KnowledgeBaseItem",
    "KnowledgebaseGet200Response",
    "KnowledgebaseIdItemsGet200Response",
    "ProductPhoneNumbersGet200Response",
    "ProductPhoneNumbersGet200ResponseDataInner",
    "ProductPhoneNumbersGet200ResponseDataInnerAttributes",
    # Webhook models
    "AgentAgentIdWebhookSubscriptionsDelete200Response",
    "AgentAgentIdWebhookSubscriptionsGet200Response",
    "AgentAgentIdWebhookSubscriptionsGet404Response",
    "AgentAgentIdWebhookSubscriptionsPost201Response",
    "AgentAgentIdWebhookSubscriptionsPost400Response",
    "AgentAgentIdWebhookSubscriptionsPostRequest",
    "Webhook",
    "WebhookAgent",
    "WebhookEvent",
    "WebhookGet200Response",
    "WebhookGet200ResponseData",
    "WebhookIdDelete404Response",
    "WebhookPost201Response",
    "WebhookPostRequest",
    "WebhookPostRequestEventsInner",
    "WebhookSubscription",
    "WebhookSubscriptionPopulated",
    # Workflow models
    "AgentIdWorkflowGet200Response",
    "AgentIdWorkflowGet200ResponseData",
    "AgentIdWorkflowGet200ResponseDataEdgesInner",
    "AgentIdWorkflowGet200ResponseDataEdgesInnerData",
    "AgentIdWorkflowGet200ResponseDataEdgesInnerMarkerEnd",
    "AgentIdWorkflowGet200ResponseDataNodesInner",
    "AgentIdWorkflowGet200ResponseDataNodesInnerData",
    "AgentIdWorkflowGet200ResponseDataNodesInnerDataVariables",
    "AgentIdWorkflowGet200ResponseDataNodesInnerDataVariablesDataInner",
    "AgentIdWorkflowGet200ResponseDataNodesInnerPosition",
    "AgentIdWorkflowGet404Response",
    # Audience models
    "AudienceGet200Response",
    "AudienceGet200ResponseDataInner",
    "AudienceIdDelete200Response",
    "AudienceIdDelete400Response",
    "AudienceIdGet200Response",
    "AudienceIdGet400Response",
    "AudienceIdGet403Response",
    "AudienceIdGet404Response",
    "AudienceIdMembersDelete200Response",
    "AudienceIdMembersDelete200ResponseData",
    "AudienceIdMembersDeleteRequest",
    "AudienceIdMembersGet200Response",
    "AudienceIdMembersGet200ResponseData",
    "AudienceIdMembersGet200ResponseDataMembersInner",
    "AudienceIdMembersGet400Response",
    "AudienceIdMembersGet500Response",
    "AudienceIdMembersPost200Response",
    "AudienceIdMembersPost200ResponseDataInner",
    "AudienceIdMembersPost200ResponseDataInnerData",
    "AudienceIdMembersPost400Response",
    "AudienceIdMembersPost403Response",
    "AudienceIdMembersPostRequest",
    "AudienceIdMembersSearchGet200Response",
    "AudienceIdMembersSearchGet200ResponseData",
    "AudienceIdMembersSearchGet200ResponseDataSearchInfo",
    "AudienceIdMembersSearchGet400Response",
    "AudienceIdMembersSearchGet500Response",
    "AudiencePost200Response",
    "AudiencePost200ResponseData",
    "AudiencePost400Response",
    # Additional models
    "AgentDTOLanguageSwitching",
    "CampaignIdGet200ResponseData",
]



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
import typing_extensions
from ....core.pydantic_utilities import IS_PYDANTIC_V2
from ....core.serialization import FieldMetadata
from ....core.unchecked_base_model import UncheckedBaseModel


class GetCampaignIdResponseDataEventsItem(UncheckedBaseModel):
    id: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="_id"), pydantic.Field(alias="_id")] = (
        None
    )
    campaign_id: typing_extensions.Annotated[
        typing.Optional[str], FieldMetadata(alias="campaignId"), pydantic.Field(alias="campaignId")
    ] = None
    trigger_source: typing_extensions.Annotated[
        typing.Optional[str], FieldMetadata(alias="triggerSource"), pydantic.Field(alias="triggerSource")
    ] = None
    event_action: typing_extensions.Annotated[
        typing.Optional[str], FieldMetadata(alias="eventAction"), pydantic.Field(alias="eventAction")
    ] = None
    created_at: typing_extensions.Annotated[
        typing.Optional[dt.datetime], FieldMetadata(alias="createdAt"), pydantic.Field(alias="createdAt")
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
